@@ -6,20 +6,14 @@
 *        Dukelskych Bojovniku 1944                         *
 *        390 03 Tabor                                      *
 *        Czech Republic                                    *
-*        Telefon: (048-I think) (0361) 32613               *
+*        Phone: 0041-361-32613                             *
 *        eMail: hubicka@limax.paru.cas.cz                  *
 *----------------------------------------------------------*
-* Copyright(c)1995 by Jan Hubicka.See README for license   *
-*                          details.                        *
+*   Copyright(c)1995,1996 by Jan Hubicka.See README for    *
+*                    licence details.                      *
 *----------------------------------------------------------*
 *  framebuffer.h   interface for framebuffer               *
 ***********************************************************/
-#if 0
-#include <vga.h>
-#include <vgagl.h>
-#include <vgakeyboard.h>
-#include <vgamouse.h>
-#endif
 
 extern void     create_bitmap ();
 extern void     drawbackground ();
